@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: CallToActionLandingSocial.py 12270 2020-05-26 04:48:53Z Trista $
+# $Id: CallToActionLandingSocial.py 12419 2020-07-23 07:57:14Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,15 +11,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $
-# $Date: 2020-05-26 13:48:53 +0900 (週二, 26 五月 2020) $
-# $Revision: 12270 $
+# $Author: Casey $
+# $Date: 2020-07-23 16:57:14 +0900 (週四, 23 七月 2020) $
+# $Revision: 12419 $
 
 from django import template
 from django.utils.safestring import mark_safe
-from django.core.urlresolvers import reverse
 from djangocms_forms.utils import int_to_hashid
 
+from Iuppiter.DjangoUtil import reverse
+
 register = template.Library()
 
 @register.simple_tag
